.. BicycleParameters documentation master file, created by
   sphinx-quickstart on Wed Jun 29 15:30:42 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
BicycleParameters's Documentation!
==================================

**BicycleParameters** is a Python program designed to produce and manipulate
the basic parameters needed for bicycle dynamic models.

.. list-table:: Example Bicycle Inertia Plot and Corresponding Eigenvalue Speed
   Plot

   * - .. image:: _images/sphx_glr_plot_benchmark_001.png
     - .. image:: _images/sphx_glr_plot_benchmark_002.png

.. figure:: https://objects-us-east-1.dream.io/mechmotum/bicycleparameters-app.png
   :target: https://bicycle-dynamics.onrender.com/

   `Bicycle Dynamics Analysis App <https://bicycle-dynamics.onrender.com/>`_ Powered by BicycleParameters

Table of Contents
=================

.. toctree::
   :maxdepth: 2

   description.rst
   installation.rst
   data.rst
   examples.rst
   gallery/index.rst
   app.rst
   bicycleparameters.rst

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
